/**
 * 钱包提供给第三方的方法
 */
import { GENERATOR_TYPE } from '../../chat/server/data/db/user.s';
import { WebViewManager } from '../../pi/browser/webview';
import { popNew } from '../../pi/ui/root';
import { getUserRecentGame } from '../net/pull';
import { addThirdPushListener } from '../postMessage/thirdPush';
import { ThirdCmd } from '../public/constant';
import { getStore, setStore } from '../store/memstore';
import { gotoSquare } from '../view/base/app';
import { closeGameFloatBox, getGameItem } from '../view/play/home/gameConfig';
import { getStoreData, getWebviewName } from './walletApi';

/**
 * 监听第三方发送的请求
 */
addThirdPushListener(ThirdCmd.GameService, (webviewName: string) => { gotoGameService(webviewName); });                       // 注册游戏客服事件
addThirdPushListener(ThirdCmd.OfficialGroup, (webviewName: string) => { gotoOfficialGroupChat(webviewName); });           // 注册官方群聊事件
addThirdPushListener(ThirdCmd.Square, (webviewName: string) => { gotoSquarePage(webviewName); });           // 注册广场事件
addThirdPushListener(ThirdCmd.Mini, (webviewName: string) => { closeFloatBox(); });           // 注册最小化游戏事件
addThirdPushListener(ThirdCmd.Close, (webviewName: string) => { closeFloatBox(); });           // 注册关闭游戏事件
/**
 * 关闭游戏悬浮窗按钮
 */
const closeFloatBox = async () => {
    closeGameFloatBox();

    try {
        const user = await getStoreData('user', {});
        const recentList = await getUserRecentGame(user.accId, 10);
        const allGameInfos = getStore('game/allGame', []);
        const recentGameData = allGameInfos.filter(v => {
            return recentList.indexOf(v.appid) > -1;
        });
        console.log('最近在玩游戏', recentGameData);
        setStore('game/oftenGame', recentGameData);

    } catch (err) {
        console.warn(err);
    }
};

/**
 * 游戏客服
 */
const gotoGameService = (webviewName: string) => {
    console.log('wallet gotoGameService called');
    const item: any = getGameItem(webviewName) || {};
    closeFloatBox();
    popNew('chat-client-app-view-chat-chat', {
        accId: item.accId, chatType: GENERATOR_TYPE.USER, name: `${item.title}官方客服`, okCB: () => {
            WebViewManager.open(webviewName, `${item.url}?${Math.random()}`, webviewName, '', item.screenMode);
        }
    });
};

/**
 * 官方群聊
 */
const gotoOfficialGroupChat = (webviewName: string) => {
    console.log('wallet gotoOfficialGroupChat called');
    const item: any = getGameItem(webviewName) || {};
    closeFloatBox();
    popNew('chat-client-app-view-chat-chat', {
        gid: item.groupId, chatType: GENERATOR_TYPE.GROUP, name: `${item.title}官方群`, okCB: () => {
            WebViewManager.open(webviewName, `${item.url}?${Math.random()}`, webviewName, '', item.screenMode);
        }
    });
};

/**
 *  广场
 */
const gotoSquarePage = (webviewName: string) => {
    console.log('wallet gotoSquarePage called');
    const item: any = getGameItem(webviewName) || {};
    closeFloatBox();
    popNew('app-components-floatBox-floatBox', { webviewName, imgUrl: item.img && item.img[0] }, null, null, null, 'force');
    gotoSquare(item.title);
};

/**
 * 关闭游戏webview
 */
export const closeGameWebview = () => {
    closeGameFloatBox();
    getWebviewName().then(name => {
        (<any>window).pi_sdk.webview.closeWebview(name);
    },err => {
        console.warn(err);
    });
};