/**
 * 钱包向 VM 通信调用的方法
 */
import { LoginType } from '../../pi/browser/thirdLogin';
import { WebViewManager } from '../../pi/browser/webview';
import { addStoreLoadedListener, isPC } from '../postMessage/vmPush';

let count = 0;
const obj = {};
/**
 * vm rpc 调用
 * rpc调用有两种模式 callback放在rpc函数调用最后面实现对同步函数的rpc调用  放置rpcData 下params参数最后面实现对异步函数的rpc调用
 * @param data 参数 
 */
export const vmRpcCall = (methodName:string,params: any[]):Promise<any> => {
    count++;
    console.log(`vmRpcCall start methodName ${methodName} params ${JSON.stringify(params)} count ${count}`);
    
    return new Promise((resolve,reject) => {
        addStoreLoadedListener(() => {
            console.log('addStoreLoadedListener');
            let count = obj[methodName] || 0;
            obj[methodName] = ++count;
            // 在params后面加入callback函数  实现对异步函数的rpc调用
            params.push(([error,res]) => { 
                if (error) reject(error);
                resolve(res);
            });
            let moduleName = 'app/remote/vm_api';
            if (isPC) {
                moduleName = 'vm/remote/vm_api';
            }
            WebViewManager.rpc('JSVM',{ 
                moduleName, 
                methodName, 
                params
            });
        });
        
    });
};

/**
 * 获取store数据
 */
export const getStoreData = (path: string,defaultValue?:any) => {
    return vmRpcCall('getStoreData',[path, defaultValue]);
};

/**
 * 更新store并通知
 */
export const setStoreData = (path: string, data: any, notified = true) => {
    return vmRpcCall('setStoreData',[path,data,notified]);
};

/**
 * websocket请求
 */
export const requestAsyncRpc = (msg: any) => {
    return vmRpcCall('requestAsyncRpc',[msg]);
};

/**
 * 去充值
 */
export const goRecharge = () => {
    return vmRpcCall('goRecharge',[]);
};

/**
 * 单独启动聊天时，获取webview名字
 */
export const getWebviewName = () => {
    return vmRpcCall('getWebviewName',[]);
};

/**
 * 尝试重连网络
 */
export const reconnect = () => {
    vmRpcCall('reconnect',[]);
};

/**
 * 绑定第三方应用
 */
export const bindThirdData = (loginType:LoginType) => {
    return new Promise((resolve,reject) => {
        window.pi_sdk.platform.bindThirdData(loginType,(error,result) => {
            if (!error) {
                resolve(result);
            } else {
                reject(error);
            }
        });
    });
    
};

/**
 * 清除账号信息
 */
export const logoutUser = () => {
    return new Promise((resolve,reject) => {
        window.pi_sdk.platform.logoutUser((error,result) => {
            if (!error) {
                resolve(result);
            } else {
                reject(error);
            }
        });
    });
};

/**
 * 获取验证码
 * @param phone 
 */
export const sendCode = (phone:string) => {
    return new Promise((resolve,reject) => {
        window.pi_sdk.platform.sendCode(phone, (error,result) => {
            if (!error) {
                resolve(result);
            } else {
                reject(error);
            }
        });
    });
};

/**
 * 绑定手机号
 */
export const bindPhoneNumber = (phone:string,code:string) => {
    return new Promise((resolve,reject) => {
        window.pi_sdk.platform.bindPhoneNumber({ phone,code },(error,result) => {
            if (!error) {
                resolve(result);
            } else {
                reject(error);
            }
        });
    });
};
