import { popNew } from '../../../pi/ui/root';
import { Widget } from '../../../pi/widget/widget';
import { getStoreData } from '../../api/walletApi';
import { exitDevice, getDeviceList } from '../../net/pull';
import { popNewMessage, timestampFormat, unicodeArray2Str } from '../../utils/pureUtils';

interface Props {
    curDevice:string; // 当前设备名字
    deviceList:DeviceInfo[]; // 设备列表
}

interface DeviceInfo {
    deviceName: string;
    cname: string;
    time: string;
    deviceId: string;
    packageName: string;
}
/**
 * 设备管理
 */
export class DeviceControl extends Widget {
    public ok:() => void;
    public props:Props = {
        deviceList:[],
        curDevice:''
    };
    
    public create() {
        super.create();
        this.init();
    }

    public async init() {
        try {
            const deviceId = await getStoreData('flags/deviceId','');
            const res = await getDeviceList();
            const list = [];
            for (const v of res.value) {
                const device = JSON.parse(unicodeArray2Str(v[4]));
                const deviceInfo = {
                    deviceName: device.deviceName,
                    cname: device.cname,
                    time: timestampFormat(v[3]).split(' ')[0],
                    deviceId: v[0],
                    packageName: v[1]
                };
                
                if (deviceId === v[0]) {
                    list.unshift(deviceInfo);  // 当前设备放在第一个
                } else {
                    list.push(deviceInfo);
                }
            }
            this.props.deviceList = list;
            console.log('获取设备列表： ', res,list);

            this.paint();
        } catch (err) {
            console.warn(err);
        }
    }

    public goBack() {
        this.ok && this.ok();
    }

    // 退出登录
    public exitDevice(ind:number) {
        const device:DeviceInfo = this.props.deviceList[ind];
        
        popNew('app-components-modalBox-modalBox', { title: '退出设备', content:`退出后在${device.deviceName}上登录需要重新验证账号` }, () => {
            exitDevice([[device.deviceId, device.packageName]]).then(res => {
                popNewMessage(`退出登录成功`);
                this.props.deviceList.splice(ind,1);
                this.paint();
                
            }, err => {
                console.warn(err);
            });
        });
        
    }

    // 退出所有其他设备
    public exitAllDevice() {
        popNew('app-components-modalBox-modalBox', { title: '退出设备', content:'退出所有非当前设备的登录，下次登录需要重新验证账号，确定退出吗？' }, () => {
            const list = [];
            for (const v of this.props.deviceList) {
                list.push([v.deviceId, v.packageName]);
            }
            list.shift();
            exitDevice(list).then(res => {
                popNewMessage(`退出登录成功`);
                this.props.deviceList.splice(1);
                this.paint();
                
            }, err => {
                console.warn(err);
            });
        });
        
    }

}