/**
 * 监听VM的store变化
 */
import { vmRpcCall } from '../api/walletApi';
import { addStoreLoadedListener } from './vmPush';

/**
 * 注册store监听 VM准备好后执行
 */
export const registerStoreData = (keyName: string, cb: Function) => {
    console.log(`registerStoreData keyName is : ${keyName}`);
    addStoreLoadedListener(() => {
        console.log(`addStoreLoadedListener exe keyName is : ${keyName}, cb is : ${cb}`);
        addStoreListener(keyName,cb);
    });
};

const handlerMap = new Map();
const registerKeys = [];
let frameId;

/**
 * 注册监听函数
 */
export const addStoreListener = (key:string,cb:Function) => {
    const handlers = handlerMap.get(key) || [];
    if (handlers.length === 0) {   // 当前key还从未被注册过
        registerKeys.push(key);   // 一次性注册的key
    }
    handlers.push(cb);
    handlerMap.set(key,handlers);
    if (!frameId && registerKeys.length > 0) {
        frameId = requestAnimationFrame(() => {   // 在下一帧之前一次性注册所有key
            console.log(`requestAnimationFrame starting`);
            const keysStr = registerKeys.join(',');
            console.log(`requestAnimationFrame keysStr is : ${keysStr}`);
            vmRpcCall('vmRegisterStore',[keysStr]);
            console.log(`requestAnimationFrame end`);
            registerKeys.length = 0;
            frameId = undefined;
        }); 
    }
    
};

/**
 * 通知监听器
 */
export const notifyListener = (key:string,data:string) => {
    console.log(`notifyListener key is : ${key}, data is : ${data}`);
    data = JSON.parse(data);
    const handlers = handlerMap.get(key) || [];
    console.log(`handlers.length is : ${handlers.length}`);
    for (const h of handlers) {
        console.log(`handler is : ${h}`);
        h && h(data);
    }
};
