
/**
 * 内存中的数据结构
 */

/**
 * 后端定义的任务id
 */
export enum TaskSid {
    Mine = '11',                // 游戏 实际上是appid
    Recharge = 301,             // 充值
    Withdraw = 302,             // 提现
    CreateWallet = 1001,        // 创建钱包
    FirstChargeEth = 1002,      // 以太坊首次转入
    BindPhone = 1003,           // 注册手机
    ChargeEth = 1004,           // 存币
    InviteFriends = 1005,       // 邀请真实好友
    BuyFinancial = 1007,        // 购买理财产品
    Transfer = 1008,            // 交易奖励
    Dividend = 1009,            // 分红
    Mining = 1010,              // 挖矿
    Chat = 1011,                // 聊天
    FinancialManagement = 330,  // 理财
    LuckyMoney = 340,           // 红包
    LuckyMoneyRetreat = 341,    // 回退红包
    Wxpay = 370,                // 微信支付
    Alipay = 371,               // 支付宝支付
    ApplePay = 372,             // iOS支付
    Consume = 360,              // 消费
    Receipt = 361               // 收款
}

/**
 * 游戏
 */
export interface GameItem {
    usePi: boolean;
    title: string;// 游戏名
    desc: string;// 游戏描述
    img: string[];// 游戏图片
    url: string;// 游戏路径
    apkDownloadUrl: string;
    webviewName: string;
    buttonMod: number;   // 当前按钮模式
    accId: string;
    groupId: number;
    appid: string;
    screenMode: string;// 横屏
}

/**
 * 红包模块
 */
export interface LuckyMoney {
    sends: LuckyMoneySendDetail[];         // 发送红包记录
    exchange: LuckyMoneyExchangeHistory;   // 兑换红包记录
    invite: LuckyMoneyExchangeHistory;     // 邀请码记录
}

/**
 * 挖矿模块
 */
export interface Mining {
    total: MiningTotal;       // 挖矿汇总信息
    history: DividendHistory; // 挖矿历史记录
    addMine: AddMineItem[];   // 矿山增加项目
    mineRank: MineRank;       // 矿山排名
    miningRank: MiningRank;   // 挖矿排名
    itemJump: string;         // 矿山增加项目跳转详情
}

/**
 * 分红模块
 */
export interface Dividend {
    total: DividendTotal;         // 分红汇总信息
    history: DividendHistory;     // 分红历史记录
}

/**
 * 活动
 */
export interface Activity {
    luckyMoney: LuckyMoney;                   // 红包
    dividend: Dividend;                       // 分红
}

/**
 * 全局store数据
 */
export interface Store {
    activity: Activity;  // 活动：红包，挖矿，分成，理财
    setting: Setting;     // 设置
    game: {
        allGame: GameItem[];
        hotGame: GameItem[];// 热门游戏
        oftenGame: GameItem[];// 最近在玩的游戏
        recommendGame: GameItem[];// 推荐游戏
        recommendedToday: GameItem[];
    };// 游戏
    flags: object;       // 全局的标识
}

/**
 * 云端账户的货币类型
 */
export enum CloudCurrencyType {
    KT = 100,  // KT
    ETH = 101,       // ETH 
    BTC = 102,       // BTC
    ST = 103,         // ST
    SC = 104        // SC 银两
}

/**
 * 红包类型
 */
export enum LuckyMoneyType {
    Normal = '00',   // 等额红包
    Random = '01',   // 随机红包
    Invite = '99'    // 邀请码
}

/**
 * 交易状态
 */
export enum TxStatus {
    Pending,     // 打包中
    Confirmed,   // 确认 >= 1个区块确认
    Failed,      // 失败
    Success      // 成功  一定的区块确认后认为succss
}

/**
 * 交易类型
 */
export enum TxType {
    Transfer = 1,    // 普通转账
    Receipt,         // 收款
    Recharge,        // 充值
    Exchange         // 币币兑换
}

/**
 * 当前用户数据
 */
export interface User {

    offline: boolean;       // 连接状态
    isLogin: boolean;      // 钱包登录状态
    allIsLogin: boolean;     // 所有服务登录状态  (钱包  活动  聊天)

    token: string;         // 自动登录token
    conUid: string;        // 服务器连接uid

}

/**
 * 用户设置
 */
export interface Setting {
    language: string;             // 语言
    topHeight: number;             // 设备头部应空出来的高度(刘海高度)
    bottomHeight: number;          // 设备底部应空出来的高度
}

/**
 * 发红包需要的货币类型
 */
export enum CloudType {
    KT = 6001,  // KT
    ETH = 4001,       // ETH 
    BTC = 3001,       // BTC
    ST = 5001        // ST
}

/**
 * 挖矿汇总信息
 */
export interface MiningTotal {
    totalNum: number; // 矿山总量
    thisNum: number;  // 本次可挖
    holdNum: number;  // 已挖数量
}

/**
 * 分红信息
 */
export interface DividendTotal {
    total: number;      // 累计分红
    thisDivid: number;  // 本次分红
    totalDays: number;  // 分红天数
    yearIncome: number; // 年华收益
}

/**
 * 挖矿，分红历史记录单项
 */
export interface DividendItem {
    num: number;
    time: string;
    total: number;
}

/**
 * 挖矿，分红历史记录
 */
export interface DividendHistory {
    list: DividendItem[];
    start: number;
    canLoadMore: boolean;
}

/**
 * 矿山增加项目
 */
export interface AddMineItem {
    isComplete: boolean;  // 是否已完成该挖矿步骤
    itemNum: number;      // 该项目已得到数量
}

/**
 * 矿山，挖矿排名单项
 */
export interface MineRankItem {
    index: number;         // 名次
    name: string;          // 用户名称
    num: number;           // 矿山，挖矿总量
}

/**
 * 矿山排名
 */
export interface MineRank {
    page: number;            // 矿山排名列表页码
    isMore: boolean;         // 矿山排名是否还有更多  
    rank: MineRankItem[];    // 矿山排名分页数据
    myRank: number;          // 当前用户的排名
}

/**
 * 挖矿排名
 */
export interface MiningRank {
    page: number;            // 挖矿排名列表页码
    isMore: boolean;         // 挖矿排名是否还有更多  
    rank: MineRankItem[];    // 挖矿排名分页数据
    myRank: number;          // 当前用户的排名
}

/**
 * 发送红包记录
 */
export interface LuckyMoneySendHistory {
    sendNumber: number;            // 发送红包总数
    start: string;                 // 翻页start
    list: LuckyMoneySendDetail[];  // 详情列表
}
/**
 * 发送红包记录详情
 */
export interface LuckyMoneySendDetail {
    rid: string;                // 红包id
    rtype: number;              // 红包类型
    ctype: number;              // 币种
    ctypeShow: string;          // 币种显示格式
    amount: number;             // 金额
    time: number;               // 时间
    timeShow: string;           // 时间显示格式
    codes: string[];            // 兑换码
    curNum: number;             // 红包已兑换个数
    totalNum: number;            // 总个数
}

/**
 * 兑换红包记录
 */
export interface LuckyMoneyExchangeHistory {
    exchangeNumber: number;                      // 兑换红包总数
    start: string;                               // 翻页start
    list: LuckyMoneyExchangeDetail[];            // 详情列表
}
/**
 * 兑换红包记录详情
 */
export interface LuckyMoneyExchangeDetail {
    suid: number;              // 发送者uid
    rid: string;               // 红包id
    rtype: number;             // 红包类型 0-普通红包，1-拼手气红包，99-邀请码
    rtypeShow: string;
    ctype: number;             // 币种
    ctypeShow: string;
    amount: number;            // 金额
    time: number;              // 时间
    timeShow: string;
}

/**
 * 红包详情
 */
export interface LuckyMoneyDetail {
    suid: number;            // 发送者uid
    cuid: number;            // 兑换者uid
    rtype: number;           // 红包类型
    ctype: number;           // 货币类型
    amount: number;          // 金额
    time: number;            // 时间
    timeShow: string;
}
