import { getStore as chatGetStore, register as chatRegister } from '../../../chat/client/app/data/store';
import { chatManualReconnect } from '../../../chat/client/app/net/init';
import { earnManualReconnect } from '../../../earn/client/app/net/init';
import { getStore as earnGetStore, register as earnRegister } from '../../../earn/client/app/store/memstore';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { getStoreData, reconnect } from '../../api/walletApi';
import { registerStoreData } from '../../postMessage/listenerStore';
// ================================ 导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');

export enum OFFLINE_TYPE {
    WALLET = 0,  // 钱包
    CHAT = 1,   // 聊天
    EARN = 2  // 活动
}

interface Props {
    offlineType: OFFLINE_TYPE;
}

const LOADING_TIME = 2000;

type State = [Array<boolean>,Array<boolean>]//[钱包是否离线，聊天是否离线，活动是否离线 ]，[钱包是否重连转圈,聊天是否重连转圈,活动是否重连转圈]

/**
 * 离线提示
 */
export class OfflineTip extends Widget {
    public props:Props;
    public state = globalState;

    /**
     * 断线重连
     */
    public reConnect() {

        if(this.state[1][this.props.offlineType])return;

        this.state[1][this.props.offlineType] = true;//这个时候globalState的值已经被改掉了，因为数组是浅拷贝
        switch(this.props.offlineType){
            case OFFLINE_TYPE.WALLET:
                getStoreData('flags/offLine').then(r => {
                    if (r) {
                        reconnect();
                    }
                },(err) => {
                    console.warn(err);
                });
                break;
            case OFFLINE_TYPE.CHAT:
                if (chatGetStore('flags/offLine')) {
                    chatManualReconnect();
                }
                break;
            case OFFLINE_TYPE.EARN:
                if (earnGetStore('userInfo/offLine')) {
                    earnManualReconnect();
                }
                break;
            default:
                break;
        }
        setTimeout(()=>{
            this.state[1][this.props.offlineType] = false
            this.paint();
        }, LOADING_TIME)

        this.paint();
    }
}

//这里用到了一个不太好的技巧，就是数组赋值的时候是浅拷贝的，所以我只有改一处state，所有的state都会被改掉，因为他们本来就是同一个
let globalState = [[true,true,true],[false,false,false]]as State;

registerStoreData('flags/offLine', (isOffline:boolean) => {
    console.log('wallet offLine--------',isOffline);
    globalState[0][OFFLINE_TYPE.WALLET] = isOffline
    if(!isOffline)globalState[1][OFFLINE_TYPE.WALLET] = false;
    forelet.paint(globalState);
});

earnRegister('userInfo/offLine', (isOffline:boolean) => {
    console.log('earn offLine--------', isOffline);
    globalState[0][OFFLINE_TYPE.EARN] = isOffline
    if(!isOffline)globalState[1][OFFLINE_TYPE.EARN] = false;
    forelet.paint(globalState);
});

chatRegister('flags/offLine', (isOffline:boolean) => {
    console.log('chat offLine--------',isOffline);
    globalState[0][OFFLINE_TYPE.CHAT] = isOffline
    if(!isOffline)globalState[1][OFFLINE_TYPE.CHAT] = false;
    forelet.paint(globalState);
});
// ===========================================================
