/**
 * 一些底层操作
 */
import { AdPlatform, ADUnion, PlayEvent } from '../../pi/browser/ad_unoin';
import { DeviceIdProvider } from '../../pi/browser/device';
import { ImagePicker } from '../../pi/browser/imagePicker';
import { appLanguageList, LocalLanguageMgr } from '../../pi/browser/localLanguage';
import { WebViewManager } from '../../pi/browser/webview';
import { setStore } from '../store/memstore';
import { piRequire } from '../utils/commonjsTools';
import { popNewLoading } from './pureUtils';

/**
 * 获取屏幕刘海与下部分高度
 */
export const getScreenModify = () => {
    WebViewManager.getScreenModify((high, low) => {
        console.log('获取屏幕刘海高度 high:', high);
        console.log('获取屏幕虚拟按键高度 low:', low);
        const calHigh = high / window.devicePixelRatio * 2;
        setStore('setting/topHeight', calHigh);
    });
};

/**
 * 图片选择
 */
export const selectImage = (ok?, cancel?) => {
    console.log('选择图片');
    const imagePicker = new ImagePicker();
    imagePicker.init();
    imagePicker.selectFromLocal({
        success: (width, height, url) => {
            ok && ok(width, height, url);
            close && close.callback(close.widget);

        },
        fail: (result) => {
            cancel && cancel(result);
            close && close.callback(close.widget);
        },
        useCamera: 1,
        single: 1,
        max: 1
    });
    let close;
    setTimeout(() => {
        close = popNewLoading({ zh_Hans: '导入中...', zh_Hant: '導入中...', en: '' });
    }, 100);

    return imagePicker;
};

/**
 * 二维码扫描
 */
export const doScanQrCode = (ok?, cancel?) => {
    piRequire(['pi/browser/qrcode']).then(mods => {
        const QRCode = mods[0].QRCode;
        const qrcode = new QRCode();
        qrcode.init();
        qrcode.scan({
            success: (res) => {
                ok && ok(res);
                console.log('scan-------------', res);
            },
            fail: (r) => {
                cancel && cancel();
                console.log(`scan fail:${r}`);
            }
        });
        qrcode.close({
            success: (r) => {
                console.log(`close result:${r}`);
            }
        });
    }).catch(err => {
        console.log('下载文件失败', err);
    });
};

/**
 * 截屏
 */
export const makeScreenShot = (okCB?, errCB?) => {
    piRequire(['pi/browser/shareToPlatforms']).then(mods => {
        const ShareToPlatforms = mods[0].ShareToPlatforms;
        ShareToPlatforms.makeScreenShot({
            success: (result) => {
                okCB && okCB(result);
            },
            fail: (result) => {
                errCB && errCB(result);
            }
        });
    }).catch(err => {
        console.log('下载文件失败', err);
    });

};

/**
 * 设置手机语言
 */
export const setAppLanguage = (language: string, okCB?, errCB?) => {
    const appLanguage = new LocalLanguageMgr();
    appLanguage.init();
    appLanguage.setAppLan({
        language: appLanguageList[language],
        success: (result) => {
            okCB && okCB(result);
        },
        fail: (result) => {
            errCB && errCB(result);
        }
    });
    appLanguage.close({
        success: (r) => {
            console.log(`close result:${r}`);
        }
    });
};

/**
 * 获取系统语言
 */
export const getSystemLanguage = (okCB?, errCB?) => {
    const appLanguage = new LocalLanguageMgr();
    appLanguage.init();
    appLanguage.getSysLan({
        success: (result) => {
            okCB && okCB(result);
        },
        fail: (result) => {
            errCB && errCB(result);
        }
    });
    appLanguage.close({
        success: (r) => {
            console.log(`close result:${r}`);
        }
    });
};

/**
 * 预先下载广告
 */
let adMgr = null;
export const preLoadAd = (adType?: AdPlatform, cb?: (str1: string, str2: string) => void) => {
    if (!adMgr) adMgr = ADUnion.getInstance();
    adType = adType ? adType : Math.random() > 0.5 ? AdPlatform.GDT : AdPlatform.CSJ;
    // adType = AdPlatform.CSJ;  // ios目前只接入了csj
    adMgr.loadRewardVideoAD(adType, (str1, str2) => {
        cb && cb(str1, str2);
    });
};
/**
 * 观看广告
 * adtype:1.广点通  2.字节跳动
 */
// tslint:disable-next-line:no-reserved-keywords
export const watchAd = (adType: AdPlatform, cb?: (isSuccess: number, event: PlayEvent, info: string) => void) => {
    // tslint:disable-next-line:no-reserved-keywords
    if (!adMgr) adMgr = ADUnion.getInstance();
    adMgr.showRewardVideoAD(adType, (isSuccess, event, info) => {
        cb && cb(isSuccess, event, info);
        preLoadAd();
    });
};

/**
 * 选择播放的广告类型
 */
export const chooseAdType = (cb: Function) => {
    if (!adMgr) adMgr = ADUnion.getInstance();
    const ads = [];
    adMgr.getADNumber((gdtAdNumber, csjAdNumber) => {
        for (let i = 0; i < gdtAdNumber; i++) {
            ads.push(AdPlatform.GDT);
        }
        for (let i = 0; i < csjAdNumber; i++) {
            ads.push(AdPlatform.CSJ);
        }
        const len = ads.length;
        const index = Math.floor(Math.random() * 100) % len;
        const adType = ads[index] || (Math.random() > 0.5 ? AdPlatform.GDT : AdPlatform.CSJ);
        cb && cb(adType);
    });
};

// 获取本地版本号
export const getLocalVersion = (cb: Function) => {
    const device = new DeviceIdProvider();
    device.getAppVerison((msg: string) => {
        cb && cb(msg);
    });
    device.close({
        success: (r) => {
            console.log(`close result:${r}`);
        }
    });
};