/**
 * 钱包问题回答
 */
import { getLang } from '../../../pi/util/lang';
import { getModulConfig } from '../../public/config';

// tslint:disable-next-line:max-func-body-length
export const getHelpAnswer = () => {
    const walletName = getModulConfig('WALLET_NAME');
    const ktShow = getModulConfig('KT_SHOW');
    const stShow = getModulConfig('ST_SHOW');
    const helpAnswer = {
        zh_Hans:[
            {
                title: '创建账户？',
                htmlStr: `<ul>
                <li class="ansLI">游客登录：</li>
                <ul>
                    <li>在首页选择游客登录，账号即创建成功，若此时退出，账号不可找回，为保险起见，建议游客绑定手机号，以免丢失账号。</li>
                </ul>
                <li class="ansLI">手机号登录：</li>
                <ul>
                    <li>在首页选择创建钱包手机号登录，若检测到有账号绑定了该手机号，将直接登录该账号，并找回云端资产（即${ktShow}和${stShow}）。</li>
                </ul>
                <li>若该手机号没有创建或绑定过账号，将会直接生成一个账号并自动绑定手机。</li>
            </ul>`
            },
            {
                title: '区块链账号',
                htmlStr: `<ul>
                <li class="ansLI">注册区块链账号</li>
                <ul>
                    <li>首页选择注册区块链账号，设置好钱包名称及交易密码后，账号即创建成功，用户可以进入备份，也可以进入游戏。</li>
                </ul>
                <li class="ansLI">助记词导入</li>
                <ul>
                    <li>输入助记词并重新设置好钱包名称及交易密码，验证成功后则钱包导入成功，即可开始该钱包的资产管理。</li>
                </ul>
                <li class="ansLI">照片导入</li>
                <ul>
                    <li>选择一张设色彩丰富的照片，并为照片设置一个密码，请记住该照片和密码，它们可以成为您找回账号的凭证。</li>
                    <li>使用创建账户时设置的照片和照片密码恢复账户，同一张照片和密码会生成同一个账户，是一种非常有效的备份手法。</li>
                </ul>
                <li class="ansLI">分享片段导入</li>
                <ul>
                    <li>输入两个您分享给好友的助记词片段，导入后建议销毁本地记录，以免被盗取。</li>
                </ul>
            </ul>`
            },
            {
                title: '怎样保证账户安全？',
                htmlStr: `<ul>
                <li>创建时即备份好助记词，将助记词保存在安全的地方，不随意泄露给他人。</li>
                <li>助记词不要截图存在手机中，也不要通过网络传输给其他设备。</li>
                <li>手机和密码要保存好，同时被他人获取也会造成资金损失。</li>
            </ul>`
            },
            {
                title: '备份？',
                htmlStr: `<ul>
                <li>在账号创建成功后，侧边栏-账户-备份中可以对助记词进行备份，也可以在任务中选择备份，将助计词抄录下来，保存到安全的地方。创建成功后，根据提示可进入备份流程，将助记计词抄录下来，最好不要截图或者利用网络传输，之后验证一次助记词是否抄录正确，即助记词备份成功。</li>
                <li class="ansLI">分享助记词片段：</li>
                <ul>
                    <li>分享助记词是指将私钥使用Shamir秘密共享技术，通过门限签名方式拆分为3个部分，任意两份即可恢复您的助记词，可以分别分享给自己、朋友、家人、朋友。请勿全部分享至朋友圈或某一个朋友。目的是为了防止用户忘记秘钥而带来不可挽回的损失。</li>
                </ul>
            </ul>`
            },
            {
                title: '注销账号？',
                htmlStr: `<ul>
                <li>打开设置，您可以选择退出账户或退出并清除信息，退出账户后可以使用密码登录，若选择退出并清除信息，则需要重新导入账号。</li>
            </ul>`
            },
            {
                title: '助记词？',
                htmlStr: `<ul>
                <li>助记词是由十几个英文单词组成的一段字符串，是私钥的另一种表现形式，和私钥一样需要保持机密，他人获取后即可获取你的全部资金。</li>
                <li>创建账号时需要保存好自己的助记词，屏幕截图或保存在可联网的设备中都不安全，最好的方式是用纸笔抄录下来保存在安全的地方。</li>
                <li>助记词可以用来恢复钱包数据，当更换设备或删除钱包后，可以通过助计词导入钱包恢复数据。</li>
                <li>HD钱包的助计词是通用的，一个钱包对应一个助记词，可以用于生成多种货币的地址。</li>
            </ul>`
            },
            {
                title: '助记词丢了怎么办？',
                htmlStr: `<ul>
                <li>我们不会保存您的助记词，一旦丢失我们无法帮助您找回，所以请一定要保管好自己的助记词。</li>
            </ul>`
            },
            {
                title: '支持货币？',
                htmlStr: `<ul>
                <li>目前支持以太坊和比特币，及部分ERC20货币，之后会支持更多其他的货币。</li>
                <li class="ansLI">货币价格来源？</li>
                <ul>
                    <li>货币价格来于源交易所实时成交价格</li>
                </ul>
            </ul>`
            },
            {
                title: '转账',
                htmlStr: `<ul>
                <li>用户在转账前仔细检查您的转账地址及数字货币种类，在核对无误后再进行转账，${walletName}将用户此笔订单的交易区块发送到区块链网路，用户此时就可利用交易哈希查询交易状态，矿工见证交易区块，在一定数量矿工见证后交易就会完成，用户交易的资产会打入目标钱包。</li>
                <li class="ansLI">矿工费</li>
                <ul>
                    <li>转账时我们不会收取您的任何费用，您所支付的费用都会给到替您打包的矿工手中，发起一笔交易时可以手动设置您愿意支付的矿工费。费用越高打包速度越快，费用越低则越慢。</li>
                    <li>矿工费可以激励矿工优先打包您的交易，如果矿工费过低，矿工没有动力去打包你的交易，可能会将您的交易延后处理，请合理设置矿工费。</li>
                </ul>
                <li class="ansLI">提币</li>
                <ul>
                    <li>无论单笔提币数量多少，每笔提币均会消耗固定费用，提币手续费将从提币数量中扣除，对应各币种，提现手续费不一致，提币到账时间以接收时间为准。</li>
                    <li>BTC手续费固定0.001ETH/笔。</li>
                    <li>ETH手续费固定取0.01ETH/笔。</li>
                </ul>
                <li class="ansLI">充值</li>
                <ul>
                    <li>打开云账户，选择“充值”，用户在充值前检查您的地址及数字币种类，在核对无误后再进行充值。</li>
                </ul>
                <li class="ansLI">币币兑换</li>
                <ul>
                    <li>换币服务由第三方平台提供支持，换币汇率取决于国内外主流交易平台的实时相对价格，另外加上矿工费用及第三方平台收取的服务费用。换币实际所得数量会因为实时价格有所浮动。换币矿工费会通过计算近期交易中矿工费得出。</li>
                </ul>
            </ul>`
            },
            {
                title: '地址和私钥？',
                htmlStr: `<ul>
                <li class="ansLI">什么是地址？</li>
                <ul>
                    <li>地址就相当于用户的银行卡号，可以随意的公开，其他用户可以往您的地址里转钱，然后就可以在您的钱包余额中查看到。</li>
                </ul>
                <li class="ansLI">地址会影响我的余额吗？</li>
                <ul>
                    <li>不影响，可以更新地址的币种模型支持多对多地址转账，默认一百个地址可以用来更新，只是为了资产安全的设计。您所有地址的余额我们会在后台求和，转币的时候也会一起转出，不影响正常使用。</li>
                </ul>
                <li class="ansLI">什么是零钱地址？</li>
                <ul>
                    <li>比特币没有账户的概念，交易就是将自己地址中的全部资金转移给其他地址，当需要支付的资金小于所拥有的资金时，需要将剩余的资金转移到自己的另一个地址（也就是零钱地址）</li>
                </ul>
                <li class="ansLI">为什么有的货币地址一样？</li>
                <ul>
                    <li>以太坊代币都是基于以太坊而存活的，所以他们的地址也都与以太坊地址相同</li>
                </ul>
                <li class="ansLI">什么是私钥？</li>
                <ul>
                    <li>私钥是钱包地址所对应的“密码”，一个私钥对应一个地址，先有私钥后有地址。私钥是由十二个随机的英文单词通过哈希计算后得到，是一串64个十六进制的字符。私钥又通过计算生成地址，且通过地址是无法反向计算出私钥的。私钥既是数字资金所有权的凭证，也是数字资金控制权的唯一凭证，泄露私钥相当于将银行卡号和密码同时告诉他人。</li>
                    <li>私钥生成后一定妥善保管，私钥不要保存至邮箱、网盘、聊天工具等触网的地方，不要截图、拍照保存至手机或电脑上，私钥不可随意告诉任何人，不要轻易将私钥导入不信任的网站及钱包应用。</li>
                </ul>
            </ul>`
            }
        ],
        zh_Hant:[
            {
                title: '創建賬戶？',
                htmlStr: `<ul>
                <li class="ansLI">遊客登錄：</li>
                <ul>
                    <li>在首頁選擇遊客登錄，賬號即創建成功，若此時退出，賬號不可找回，為保險起見，建議遊客綁定手機號，以免丟失賬號。</li>
                </ul>
                <li class="ansLI">手機號登錄：</li>
                <ul>
                    <li>在首頁選擇創建錢包手機號登錄，若檢測到有賬號綁定了該手機號，將直接登錄該賬號，並找回雲端資產（即${ktShow}和${stShow}）。</li>
                </ul>
                <li>若該手機號沒有創建或綁定過賬號，將會直接生成一個賬號並自動綁定手機。</li>
            </ul>`
            },
            {
                title: '區塊鏈賬號',
                htmlStr: `<ul>
                <li class="ansLI">註冊區塊鏈賬號</li>
                <ul>
                    <li>首頁選擇註冊區塊鏈賬號，設置好錢包名稱及交易密碼後，賬號即創建成功，用戶可以進入備份，也可以進入遊戲。</li>
                </ul>
                <li class="ansLI">助記詞導入</li>
                <ul>
                    <li>輸入助記詞並重新設置好錢包名稱及交易密碼，驗證成功後則錢包導入成功，即可開始該錢包的資產管理。</li>
                </ul>
                <li class="ansLI">照片導入</li>
                <ul>
                    <li>選擇一張設色彩豐富的照片，並為照片設置一個密碼，請記住該照片和密碼，它們可以成為您找回賬號的憑證。</li>
                    <li>使用創建賬戶時設置的照片和照片密碼恢復賬戶，同一張照片和密碼會生成同一個賬戶，是一種非常有效的備份手法。</li>
                </ul>
                <li class="ansLI">分享片段導入</li>
                <ul>
                    <li>輸入兩個您分享給好友的助記詞片段，導入後建議銷毀本地記錄，以免被盜取。</li>
                </ul>
            </ul>`
            },
            {
                title: '怎樣保證賬號安全？',
                htmlStr: `<ul>
                <li>創建時即備份好助記詞，將助記詞保存在安全的地方，不隨意洩露給他人。</li>
                <li>助記詞不要截圖存在手機中，也不要通過網絡傳輸給其他設備。</li>
                <li>手機和密碼要保存好，同時被他人獲取也會造成資金損失。</li>
            </ul>`
            },
            {
                title: '備份？',
                htmlStr: `<ul>
                <li>在賬號創建成功後，側邊欄-賬戶-備份中可以對助記詞進行備份，也可以在任務中選擇備份，將助計詞抄錄下來，保存到安全的地方。創建成功後，根據提示可進入備份流程，將助記計詞抄錄下來，最好不要截圖或者利用網絡傳輸，之後驗證一次助記詞是否抄錄正確，即助記詞備份成功。</li>
                <li class="ansLI">分享助記詞片段：</li>
                <ul>
                    <li>分享助記詞是指將私鑰使用Shamir秘密共享技術，通過門限簽名方式拆分為3個部分，任意兩份即可恢復您的助記詞，可以分別分享給自己、朋友、家人、朋友。請勿全部分享至朋友圈或某一個朋友。目的是為了防止用戶忘記秘鑰而帶來不可挽回的損失。</li>
                </ul>
            </ul>`
            },
            {
                title: '註銷賬號？',
                htmlStr: `<ul>
                <li>打開設置，您可以選擇退出賬戶或退出並清除信息，退出賬戶後可以使用密碼登錄，若選擇退出並清除信息，則需要重新導入賬號。</li>
            </ul>`
            },
            {
                title: '助記詞？',
                htmlStr: `<ul>
                <li>助記詞是由十幾個英文單詞組成的一段字符串，是私鑰的另一種表現形式，和私鑰一樣需要保持機密，他人獲取後即可獲取你的全部資金。</li>
                <li>創建賬號時需要保存好自己的助記詞，屏幕截圖或保存在可聯網的設備中都不安全，最好的方式是用紙筆抄錄下來保存在安全的地方。</li>
                <li>助記詞可以用來恢復錢包數據，當更換設備或刪除錢包後，可以通過助計詞導入錢包恢復數據。</li>
                <li>HD錢包的助計詞是通用的，一個錢包對應一個助記詞，可以用於生成多種貨幣的地址。</li>
            </ul>`
            },
            {
                title: '助記詞丟了怎麼辦？',
                htmlStr: `<ul>
                <li>我們不會保存您的助記詞，一旦丟失我們無法幫助您找回，所以請一定要保管好自己的助記詞。</li>
            </ul>`
            },
            {
                title: '支持貨幣？',
                htmlStr: `<ul>
                <li>目前支持以太坊和比特幣，及部分ERC20貨幣，之後會支持更多其他的貨幣。</li>
                <li class="ansLI">貨幣價格來源？</li>
                <ul>
                    <li>貨幣價格來於源交易所實時成交價格</li>
                </ul>
            </ul>`
            },
            {
                title: '轉賬',
                htmlStr: `<ul>
                <li>用戶在轉賬前仔細檢查您的轉賬地址及數字貨幣種類，在核對無誤後再進行轉賬，${walletName}將用戶此筆訂單的交易區塊發送到區塊鍊網路，用戶此時就可利用交易哈希查詢交易狀態，礦工見證交易區塊，在一定數量礦工見證後交易就會完成，用戶交易的資產會打入目標錢包。</li>
                <li class="ansLI">礦工費</li>
                <ul>
                    <li>轉賬時我們不會收取您的任何費用，您所支付的費用都會給到替您打包的礦工手中，發起一筆交易時可以手動設置您願意支付的礦工費。費用越高打包速度越快，費用越低則越慢。</li>
                    <li>礦工費可以激勵礦工優先打包您的交易，如果礦工費過低，礦工沒有動力去打包你的交易，可能會將您的交易延後處理，請合理設置礦工費。</li>
                </ul>
                <li class="ansLI">提幣</li>
                <ul>
                    <li>無論單筆提幣數量多少，每筆提幣均會消耗固定費用，提幣手續費將從提幣數量中扣除，對應各幣種，提現手續費不一致，提幣到賬時間以接收時間為準。</li>
                    <li>BTC手續費固定0.001ETH/筆。</li>
                    <li>ETH手續費固定取0.01ETH/筆。</li>
                </ul>
                <li class="ansLI">充值</li>
                <ul>
                    <li>打開雲賬戶，選擇“充值”，用戶在充值前檢查您的地址及數字幣種類，在核對無誤後再進行充值。</li>
                </ul>
                <li class="ansLI">幣幣兌換</li>
                <ul>
                    <li>換幣服務由第三方平台提供支持，換幣匯率取決於國內外主流交易平台的實時相對價格，另外加上礦工費用及第三方平台收取的服務費用。換幣實際所得數量會因為實時價格有所浮動。換幣礦工費會通過計算近期交易中礦工費得出。</li>
                </ul>
            </ul>`
            },
            {
                title: '地址和私鑰？',
                htmlStr: `<ul>
                <li class="ansLI">什麼是地址？</li>
                <ul>
                    <li>地址就相當於用戶的銀行卡號，可以隨意的公開，其他用戶可以往您的地址裡轉錢，然後就可以在您的錢包餘額中查看到。</li>
                </ul>
                <li class="ansLI">地址會影響我的餘額嗎？</li>
                <ul>
                    <li>不影響，可以更新地址的幣種模型支持多對多地址轉賬，默認一百個地址可以用來更新，只是為了資產安全的設計。您所有地址的餘額我們會在後台求和，轉幣的時候也會一起轉出，不影響正常使用。</li>
                </ul>
                <li class="ansLI">什麼是零錢地址？</li>
                <ul>
                    <li>比特幣沒有賬戶的概念，交易就是將自己地址中的全部資金轉移給其他地址，當需要支付的資金小於所擁有的資金時，需要將剩餘的資金轉移到自己的另一個地址（也就是零錢地址）</li>
                </ul>
                <li class="ansLI">為什麼有的貨幣地址一樣？</li>
                <ul>
                    <li>以太坊代幣都是基於以太坊而存活的，所以他們的地址也都與以太坊地址相同</li>
                </ul>
                <li class="ansLI">什麼是私鑰？</li>
                <ul>
                    <li>私鑰是錢包地址所對應的“密碼”，一個私鑰對應一個地址，先有私鑰後有地址。私鑰是由十二個隨機的英文單詞通過哈希計算後得到，是一串64個十六進制的字符。私鑰又通過計算生成地址，且通過地址是無法反向計算出私鑰的。私鑰既是數字資金所有權的憑證，也是數字資金控制權的唯一憑證，洩露私鑰相當於將銀行卡號和密碼同時告訴他人。</li>
                    <li>私鑰生成後一定妥善保管，私鑰不要保存至郵箱、網盤、聊天工具等觸網的地方，不要截圖、拍照保存至手機或電腦上，私鑰不可隨意告訴任何人，不要輕易將私鑰導入不信任的網站及錢包應用。</li>
                </ul>
            </ul>`
            }
        ],
        en:``
    };

    return helpAnswer[getLang()];
};