
import { LoginType } from '../../../pi/browser/thirdLogin';
import { popNew } from '../../../pi/ui/root';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { closeGameWebview } from '../../api/thirdApi';
import { bindThirdData, getStoreData, logoutUser } from '../../api/walletApi';
import { uploadFile } from '../../net/pull';
import { registerStoreData } from '../../postMessage/listenerStore';
import { setStore } from '../../store/memstore';
import { piRequire } from '../../utils/commonjsTools';
import { popNewMessage, rippleShow } from '../../utils/pureUtils';
import { changeWalletName, changeWalletNote, changeWalletSex, hidPhoneNumber, imgResize, logoutAccount } from '../../utils/tools';
import { loadSettingSource } from '../base/sourceLoaded';
// ================================ 导出
// tslint:disable-next-line:no-reserved-keywords 
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');
interface Props {
    chooseImage: boolean;
    avatarHtml: string;  // 上传图片拼接div
    avatar: string; // 头像 上层传下来的值
    hidPhoneNumber: Function;
}

/**
 * account home
 */
export class AccountHome extends Widget {
    public ok: () => void;
    public state: State = STATE;
    public props: Props = {
        chooseImage: false,
        avatarHtml: '',
        avatar: '',
        hidPhoneNumber
    };

    public setProps(props: any) {
        this.props = {
            ...this.props,
            ...props
        };
        this.init();
    }

    public init() {
        getStoreData('user/info', {}).then((userInfo) => {
            this.state.userinfo = userInfo;
            this.paint();
        }, (err) => {
            console.warn(err);
        });
        getStoreData('flags/deviceName', '').then(name => {
            this.state.curDevice = name;
            this.paint();
        }, (err) => {
            console.warn(err);
        });
    }

    /**
     * 返回上一页
     */
    public backPrePage() {
        this.ok && this.ok();
    }

    // 动画效果执行
    public onShow(e: any) {
        rippleShow(e);
    }

    public uploadAvatar() {
        piRequire(['app/utils/native']).then((r) => {
            const imagePicker = r[0].selectImage((width, height, url) => {
                console.log('selectImage url = ', url);
                if (!url) {
                    return;
                }
                // tslint:disable-next-line:max-line-length
                this.props.avatarHtml = `<div style="background-image: url(${url});width: 80px;height: 80px;background-size: cover;background-position: center;background-repeat: no-repeat;border-radius:50%"></div>`;
                this.props.chooseImage = true;
                this.props.avatar = url;
                this.paint();
                imagePicker.getContent({
                    quality: 70,
                    success(buffer: ArrayBuffer) {
                        imgResize(buffer, (res) => {
                            uploadFile(res.base64);
                        });
                        imagePicker.close({
                            success: res => {
                                console.log('imagePicker close', res);
                            }
                        });
                    }
                });
            });
        }).catch(err => {
            console.log('下载文件失败');
        });

    }

    /**
     * 修改名称
     */
    public changeName() {
        const loading = popNew('app-publicComponents-loading-loading1');
        this.loadSetting(() => {
            popNew('chat-client-app-widget-pageEdit-pageEdit', { title: '修改昵称', contentInput: this.state.userinfo.nickName, maxLength: 10 },
                async (res: any) => {
                    await changeWalletName(res.content);
                    this.state.userinfo.nickName = res.content;
                    popNewMessage('修改昵称成功');
                    this.paint();
                });
            loading.callback(loading.widget);
        });
    }

    /**
     * 修改个性签名
     */
    public changeSignature() {
        const loading = popNew('app-publicComponents-loading-loading1');
        this.loadSetting(() => {
            popNew('chat-client-app-widget-pageEdit-pageEdit', { title: '修改个性签名', contentInput: this.state.userinfo.note, maxLength: 140 },
                (res: any) => {
                    changeWalletNote(res.content);
                    this.state.userinfo.note = res.content;
                    popNewMessage('修改个性签名成功');
                    this.paint();
                });
            loading.callback(loading.widget);
        });

    }

    /**
     * 注销账户
     */
    public logOutDel() {
        const loading = popNew('app-publicComponents-loading-loading1');
        this.loadSetting(() => {
            popNew('app-components-modalBox-modalBox', { title: '确认退出', content: '' }, () => {
                // 清除账号数据
                logoutUser().then(() => {
                    logoutAccount();
                    setStore('flags/authorized', false);
                    closeGameWebview();
                    this.backPrePage();

                }, (err) => {
                    console.warn(err);
                });

            });

            loading.callback(loading.widget);
        });

    }

    public loadSetting(cb: any) {
        loadSettingSource().then(cb, err => {
            console.warn(err);
        });
    }

    /** 
     * 选择性别
     */
    public changeSex() {
        popNew('app-components1-checkSex-checkSex', { title: '选择性别', active: this.state.userinfo.sex }, async (r: any) => {
            await changeWalletSex(r);
            this.state.userinfo.sex = r;
            popNewMessage('修改性别成功');
            this.paint();
        });
    }

    /**
     * 设备管理
     */
    public deviceControl() {
        if (!this.state.userinfo.phoneNumber) {
            popNewMessage('请先绑定手机号');

            return;
        }
        popNew('app-components-deviceControl-deviceControl');
    }

    // =========================只能绑定一次==================
    /**
     * 绑定手机号
     */
    public changePhone() {
        if (this.state.userinfo.phoneNumber) {
            popNewMessage('已绑定手机号，无法重复绑定');

            return;
        }
        const loading = popNew('app-publicComponents-loading-loading1');
        this.loadSetting(() => {
            popNew('app-view-setting-phone');
            loading.callback(loading.widget);
        });
    }

    /**
     * 绑定QQ
     */
    public changeQQ() {
        if (this.state.userinfo.QQ) {
            popNewMessage('已绑定QQ，无法重复绑定');

            return;
        }
        bindThirdData(LoginType.QQ).then(r => {
            console.log('绑定QQ成功', r);
            popNewMessage('绑定QQ成功');
        }, (err) => {
            if (err.type === 1024 || err.type === 1021) {
                popNewMessage('该账号已存在');
            } else {
                popNewMessage('绑定QQ失败');
            }
            console.warn(err);
        });
    }

    /**
     * 绑定微信
     */
    public changeWechat() {
        if (this.state.userinfo.WeChat) {
            popNewMessage('已绑定微信，无法重复绑定');

            return;
        }
        bindThirdData(LoginType.WeChat).then(r => {
            console.log('绑定微信成功', r);
            popNewMessage('绑定微信成功');
        }, (err) => {
            if (err.type === 1024 || err.type === 1021) {
                popNewMessage('该账号已存在');
            } else {
                popNewMessage('绑定微信失败');
            }
            console.warn(err);
        });
    }

    /**
     * 绑定微博
     */
    public changeWeibo() {
        if (this.state.userinfo.WeiBo) {
            popNewMessage('已绑定微博，无法重复绑定');

            return;
        }
        bindThirdData(LoginType.WeiBo).then(r => {
            console.log('绑定微博成功', r);
            popNewMessage('绑定微博成功');
        }, (err) => {
            if (err.type === 1024 || err.type === 1021) {
                popNewMessage('该账号已存在');
            } else {
                popNewMessage('绑定微博失败');
            }
            console.warn(err);
        });
    }
}
interface State {
    userinfo: {
        nickName: string;           // 昵称
        avatar: string;             // 头像
        phoneNumber: string;        // 手机号
        sex: number;       // 性别  0男 1女 2未知
        note: string;
        QQ: string;
        WeChat: string;
        WeiBo: string;
    };
    curDevice: string;
}
const STATE = {
    userinfo: {
        nickName: '',           // 昵称
        avatar: '',             // 头像
        phoneNumber: '',        // 手机号
        sex: 2,       // 性别  0男 1女 2未知
        note: '',
        QQ: '',
        WeChat: '',
        WeiBo: ''
    },
    curDevice: ''  // 当前登陆的设备
};
registerStoreData('user/info', (r) => {
    if (!r) return;
    STATE.userinfo = r;
    forelet.paint(STATE);
});
registerStoreData('flags/deviceName', (r) => {
    STATE.curDevice = r;
    forelet.paint(STATE);
});