// ================================ 导入
import { register as ChatRegister } from '../../../chat/client/app/data/store';
import { TAB } from '../../../chat/client/app/view/home/contact';
import { register as earnRegister } from '../../../earn/client/app/store/memstore';
import { popNew } from '../../../pi/ui/root';
import { setLang } from '../../../pi/util/lang';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { checkAuthorize } from '../../net/login';
import { registerStoreData } from '../../postMessage/listenerStore';
import { getModulConfig } from '../../public/config';
import { getStore, register, setStore } from '../../store/memstore';
import { piLoadDir } from '../../utils/commonjsTools';
import { getUserInfo, rippleShow } from '../../utils/pureUtils';

// ================================ 导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');

interface Old {
    isActive: string;
}
interface TaBar {
    modulName: string;
    text: object;
    icon: string;
    iconActive: string;
    components: string;
}
interface Props {
    types: number; // 页面切换的模式 支持3种模式，惰性加载0-隐藏显示切换，切换采用加载1-销毁模式，一次性加载2-隐藏显示切换
    isActive: string; // 当前活跃的页面
    old: Old;
    tabBarList: TaBar[];
    tabBarAnimateClasss: string;
    userInfo: {
        nickName: string;
        avatar: string;
    };
    gameName: string;
    activeTab: string;
}
const TabBarList = [
    {
        modulName: 'APP_PLAY',
        text: { zh_Hans: '游戏', zh_Hant: '游戏', en: '' },
        icon: 'play.png',
        iconActive: 'play_active.png',
        components: 'app-view-play-home-home'
    }, {
        modulName: 'APP_CHAT',
        text: { zh_Hans: '广场', zh_Hant: '广场', en: '' },
        icon: 'chat.png',
        iconActive: 'chat_active.png',
        components: 'chat-client-app-view-home-contact'
    }
    // , {
    //     modulName: 'APP_EARN',
    //     text: { zh_Hans: '任务', zh_Hant: '任务', en: '' },
    //     icon: 'earn.png',
    //     iconActive: 'earn_active.png',
    //     components: 'earn-client-app-view-home-home'
    // }
    , {
        modulName: 'APP_WALLET',
        text: { zh_Hans: '我的', zh_Hant: '我的', en: '' },
        icon: 'wallet.png',
        iconActive: 'wallet_active.png',
        components: 'app-view-base-myHome'
    }
];

/**
 * 首页
 */
export class App extends Widget {
    public props: Props;
    public old: Old = { isActive: 'APP_WALLET' };
    public create() {
        super.create();
        this.init();
    }

    public init(): void {
        this.props = {
            types: 1, // 用户可以单击选项，来切换卡片。支持3种模式，惰性加载0-隐藏显示切换，切换采用加载1-销毁模式，一次性加载2-隐藏显示切换。
            isActive: 'APP_PLAY',
            old: this.old,
            tabBarList: TabBarList,
            tabBarAnimateClasss: '',
            userInfo: {
                nickName: '',
                avatar: ''
            },
            gameName: '',
            activeTab: TAB.square
        };

        this.props.tabBarList = this.props.tabBarList.filter(item => {
            return getModulConfig(item.modulName);
        });
        console.log('app ', this.props);
        getUserInfo().then(userInfo => {
            console.log('app userInfo = ', userInfo);
            this.props.userInfo = userInfo;
            this.paint();
        });

    }

    public setProps(props: any) {
        this.props = {
            ...this.props,
            ...props
        };
        if (props.gameName) {
            this.props.isActive = 'APP_CHAT';
        }
        super.setProps(this.props);
    }

    public findPage(isActive: string) {
        return this.props.tabBarList.filter(item => {
            return item.modulName === isActive;
        })[0].components;
    }

    public async tabBarChangeListener(event: any, index: number) {
        if (!checkAuthorize()) {

            return;
        }
        if (!getStore('flags', {}).firstPageLoaded) {
            const loading = popNew('app-publicComponents-loading-loading1');
            const firstPage = [
                'earn/xlsx/item.c.js',
                'earn/xlsx/item.s.js',
                'earn/xlsx/awardCfg.c.js',
                'earn/xlsx/awardCfg.s.js',
                'earn/client/app/components/noviceTaskAward/',
                'earn/client/app/res/css/',
                'earn/client/app/view/home/'
            ];
            await piLoadDir(firstPage);
            loading.callback(loading.widget);
            setStore('flags/firstPageLoaded', true);
        }
        rippleShow(event);
        const identfy = this.props.tabBarList[index].modulName;
        if (this.props.isActive === identfy) return;
        this.old.isActive = this.props.isActive;
        this.props.isActive = identfy;
        this.paint();

    }

    /**
     * 首页资源加载完成后更新切换卡片模式
     */
    public initTabBarStyle() {
        this.props.types = 2;   // 全部加载
        this.paint();
    }

    public switchToEarn() {
        this.props.isActive = 'APP_EARN';
        this.paint();
    }

    public switchToSquare(gameName: string) {
        this.props.isActive = 'APP_CHAT';
        this.props.gameName = gameName;  // 从游戏内跳到广场页
        this.props.activeTab = 'square';
        this.paint();

        // 下次切换一级页面是不会固定在某个游戏标签下
        setTimeout(() => {
            this.props.gameName = '';
        }, 100);
    }
    public setActiveTab(e) {
        this.props.activeTab = e.activeTab;
        this.paint();
    }

    public switchToPlay() {
        this.props.isActive = 'APP_PLAY';
        this.paint();
    }

    public changeChatIcon(fg: boolean) {
        if (fg) {
            this.props.tabBarList[1].iconActive = 'chat_active_unRead.png';
            this.props.tabBarList[1].icon = 'chat_unRead.png';
        } else {
            this.props.tabBarList[1].iconActive = 'chat_active.png';
            this.props.tabBarList[1].icon = 'chat.png';
        }
        this.paint();
    }

    /**
     * 个人主页
     */
    public myHome() {
        if (!checkAuthorize()) {

            return;
        }
        // this.props.isActive = 'APP_WALLET';
        // this.paint();
    }

}

// ===================================================== 本地

// ===================================================== 立即执行

// localStorage key
export const SettingLanguage = 'language';

// 语言配置
register('setting/language', (r) => {
    localStorage.setItem(SettingLanguage, r);
    setLang(r);
}, false);

register('flags/firstPageLoaded', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    w && w.initTabBarStyle();
}, false);

// 监听活动页面
earnRegister('flags/earnHomeHidden', (earnHomeHidden: boolean) => {
    const w = forelet.getWidget(WIDGET_NAME);
    if (earnHomeHidden) {
        w.props.tabBarAnimateClasss = 'put-out-down';
    } else {
        w.props.tabBarAnimateClasss = 'reset-put-out';
    }
    w.paint();
});

// 监听聊天是否有未读消息
ChatRegister('flags/unReadFg', (fg) => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    w && w.changeChatIcon(fg);
});

export const gotoSquare = (gameName?: string) => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    w && w.switchToSquare(gameName);
};

export const gotoEarn = () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    w && w.switchToEarn();
};

export const gotoPlay = () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    w && w.switchToPlay();
};

registerStoreData('user', (user => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        getUserInfo().then(userInfo => {
            w.props.userInfo = userInfo;
            w.paint();
        });
    }
}));