/**
 * 云端绑定手机
 */
// =================================================导入
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { bindPhoneNumber, sendCode } from '../../api/walletApi';
import { popNewMessage } from '../../utils/pureUtils';
// ================================ 导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');
const limitTime = 60;  // 倒计时60秒

export class BindPhone extends Widget {
    public ok: () => void;
    public timer:number;
    public create() {
        this.props = {
            areaCode:'',
            phone:'',
            code:[],
            isSuccess:true,
            changePhone:false,
            countdown: 0
        };
        super.create();
    }

    public setProps(props:any,oldProps:any) {
        this.props = {
            ...this.props,
            ...props
        };
        super.setProps(this.props,oldProps);
    }
    public backPrePage() {
        this.ok && this.ok();
    }
    public jumpClick() {
        this.ok && this.ok();
    }
    
    /**
     * 输入完成后确认
     */
    public async doSure() {
        bindPhoneNumber(this.props.phone, this.props.code.join('')).then(r => {
            console.log('绑定手机号成功',r);
            popNewMessage('绑定手机号成功');
            this.backPrePage();

        }, (err) => {
            console.warn(err);
            if (err.type === 1024 || err.type === 1021) {
                popNewMessage('该账号已存在');
            
            } else if (err.type === -301) {
                popNewMessage('验证码错误');

            } else if (err.type === -300) {
                popNewMessage('验证码超时');

            } else {
                popNewMessage('绑定手机号失败');
            }

            this.props.code = [];
            this.setCode();
        });
    }

    /**
     * 手机号改变
     */
    public phoneChange(e: any) {
        this.props.phone = e.value.toString();  
    }

    /**
     * 获取验证码
     */
    public getCode() {
        this.inputBlur();
        if (!this.props.phone || !this.phoneJudge()) {
            popNewMessage('无效的手机号');

            return;
        }
        sendCode(this.props.phone);
        this.props.countdown = limitTime;
        clearTimeout(this.timer);
        this.openTimer();
        this.paint();
    }

    /**
     * 判断手机号是否符合规则
     */
    public phoneJudge() {
        const reg1 = /^[1][3-8]\d{9}$|^([6|9])\d{7}$|^[0][9]\d{8}$|^[6]([8|6])\d{5}$/;
        const reg2 = /^[1][3-8]\d{9}$|^([6|9])\d{7}$|^[0][9]\d{8}$|^[6]([8|6])\d{5}$/;        
        if (this.props.oldCode === 86) {
            return reg1.test(this.props.phone);
        } else {
            return reg2.test(this.props.phone);
        }
    }

    /**
     * 输入框取消聚焦
     */
    public inputBlur() {
        const inputs: any = document.getElementsByTagName('input');
        for (let i = 0;i < inputs.length;i++) {
            inputs[i].blur();
        }
    }

    /**
     * 手动为验证码输入框赋值
     */
    public setCode() {
        for (let i = 0;i < 4;i++) {
            (<any>document.getElementById('codeInput' + i)).value = this.props.code[i];
        }
    }

    /**
     * 验证码改变
     */
    public codeChange(e: any) {
        const v = Number(e.key) ? e.key :e.currentTarget.value.slice(-1);
        if (e.key === 'Backspace') {
            this.props.code.pop();
            const ind = this.props.code.length;
            if (ind >= 0) {
                document.getElementById('codeInput' + ind).focus();
            }
            this.setCode();
            
        } else if (this.integerJudge(v)) {
            this.props.code.push(v);
            const ind = this.props.code.length;
            document.getElementById('codeInput' + (ind - 1)).blur();
            if (ind < 4) {
                document.getElementById('codeInput' + ind).focus();
            }
        }
        console.log(v,this.props.code.length);
        this.paint();
        
        setTimeout(() => {
            if (this.props.code.length === 4) {
                this.doSure();
            }
        }, 100);
    }

    /**
     * 验证码输入框聚焦
     */
    public codeFocus() {
        const ind = this.props.code.length; 
        const elem = document.getElementById('codeInput' + ind);
        elem && elem.focus();
        this.paint();
    }

    /**
     * 判断是否是整数
     */
    public integerJudge(num:string) {
        const reg = /^[0-9]$/;
        
        return reg.test(num);
    }

    /**
     * 开启倒计时
     */
    private openTimer() {
        this.timer = setTimeout(() => {
            if (this.props.countdown <= 0) return;
            this.openTimer();
            this.props.countdown--;
            this.paint();
        }, 1000);
    }
}
