/**
 * cloud wallet home
 */
import { popNew } from '../../../pi/ui/root';
import { getLang } from '../../../pi/util/lang';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { getAccountDetail, getRechargeLogs, getWithdrawLogs } from '../../net/pull';
import { CloudCurrencyType } from '../../store/interface';
import { getCloudBalances, getStore, register } from '../../store/memstore';
// tslint:disable-next-line:max-line-length
import { fetchBalanceValueOfCoin, fetchCoinGain, formatBalance, formatBalanceValue, getCurrencyUnitSymbol, popNewMessage } from '../../utils/tools';
import { KT_SHOW, SC_SHOW } from '../../config';
// ===================================================== 导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');
interface Props {
    currencyName: string;
}
export class CloudWalletHome extends Widget {
    public props: any = {
        activeNum: 0,
    };
    public ok: () => void;
    public language: any;
    public setProps(props: Props, oldProps: Props) {
        this.language = this.config.value[getLang()];
        const currencyName = props.currencyName;
        const balance = formatBalance(getCloudBalances().get(CloudCurrencyType[currencyName]));
        const balanceValue = formatBalanceValue(fetchBalanceValueOfCoin(currencyName, balance));
        const color = getStore('setting/changeColor', 'redUp');
        this.props = {
            ...this.props,
            currencyName,
            topBarTitle: props.currencyName,
            tabs: [{
                tab: this.language.recharge,
                components: 'blockchain-view-cloudWallet-rechargeRecord'
            }, {
                tab: this.language.withdraw,
                components: 'blockchain-view-cloudWallet-withdrawRecord'
            }],
            gain: fetchCoinGain(currencyName),
            rate: formatBalanceValue(fetchBalanceValueOfCoin(currencyName, 1)),
            balance,
            balanceValue,
            currencyUnitSymbol: getCurrencyUnitSymbol(),
            redUp: color === 'redUp'
        };
        getAccountDetail(this.props.currencyName, 0);
        getRechargeLogs(this.props.currencyName);
        getWithdrawLogs(this.props.currencyName);
        super.setProps(this.props, oldProps);
    }


    public updateBalance() {
        const currencyName = this.props.currencyName;
        this.props.balance = getCloudBalances().get(CloudCurrencyType[currencyName]);
        this.props.balanceValue = formatBalanceValue(fetchBalanceValueOfCoin(currencyName, this.props.balance));
        this.paint();
    }

    public tabsChangeClick(event: any, value: number) {
        this.props.activeNum = value;
        this.paint();
    }

    public backPrePage() {
        this.ok && this.ok();
    }
    /**
     * 充值
     */
    public rechargeClick() {
        popNew('blockchain-view-cloudWallet-recharge', { currencyName: this.props.currencyName });
    }
    /**
     * 提币
     */
    public withdrawClick() {
        popNew('blockchain-view-cloudWallet-withdraw', { currencyName: this.props.currencyName });
    }
}

// ===========================

// 余额变化
register('cloud/cloudWallets', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateBalance();
    }
});

// 汇率变化
register('third/USD2CNYRate', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateBalance();
    }
});

// 涨跌幅变化
register('third/currency2USDTMap', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateBalance();
    }
});
