/**
 * create a wallet by image
 */
import { popNew } from '../../../pi/ui/root';
import { getLang } from '../../../pi/util/lang';
import { Widget } from '../../../pi/widget/widget';
import { ahashToArgon2Hash, CreateWalletType } from '../../logic/localWallet';
import { selectImage } from '../../logic/native';
import { setStore } from '../../store/memstore';
import { popNewMessage, getLength } from '../../utils/tools';

export class CreateWalletByImage extends Widget {
    public cancel: () => void;
    public ok: () => void;
    public setProps(props: any, oldProps: any) {
        this.props = {
            ...props,
            chooseImage: false,
            imageHtml: '',
            imagePsw: '',
            imagePswAvailable: false,
            imagePicker: null,
            canClick: false
        };
        super.setProps(this.props, oldProps);
    }
    public backPrePage() {
        this.cancel && this.cancel();
    }
    public selectImageClick() {
        this.props.imagePicker = selectImage((width, height, url) => {
            console.log('selectImage url = ', url);
            // tslint:disable-next-line:max-line-length
            this.props.imageHtml = `<div style="background-image: url(${url});width: 100%;height: 100%;position: absolute;top: 0;background-size: cover;background-position: center;background-repeat: no-repeat;"></div>`;
            this.props.chooseImage = true;
            this.canClick();
            this.paint();
        });

    }

    public imagePswClick() {
        // 防止事件冒泡  on-tap事件已经处理
    }

    public canClick() {
        if (this.props.chooseImage && this.props.imagePswAvailable) {
            this.props.canClick = true;
        } else {
            this.props.canClick = false;
        }
    }
    public imagePswChange(e: any) {
        this.props.imagePsw = e.value;
        // /([\u4e00-\u9fa5]{4,})|([A-Za-z]{8,})/
        this.props.imagePswAvailable = getLength(this.props.imagePsw) >= 8;
        this.canClick();
        this.paint();
    }

    public nextClick() {
        if (!this.props.canClick) return;
        if (!this.props.chooseImage) {
            const tips = { zh_Hans: '请选择照片', zh_Hant: '請選擇照片', en: '' };
            popNewMessage(tips[getLang()]);

            return;
        }
        if (!this.props.imagePswAvailable) {
            const tips = { zh_Hans: '字符错误', zh_Hant: '字符錯誤', en: '' };
            popNewMessage(tips[getLang()]);

            return;
        }
        const imagePsw = this.props.imagePsw;
        const imgArgon2HashPromise = new Promise((resolve) => {
            this.props.imagePicker.getAHash({
                success(ahash: string) {
                    console.log('image ahash = ', ahash);
                    resolve(ahashToArgon2Hash(ahash, imagePsw));
                }
            });
        });
        setStore('flags/imgArgon2HashPromise', imgArgon2HashPromise);
        popNew('blockchain-view-create-createWallet', { itype: CreateWalletType.Image }, () => {
            this.ok && this.ok();
        });
    }
}
