/**
 * transaction home
 */
import { popNew } from '../../../pi/ui/root';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { dataCenter } from '../../logic/dataCenter';
import { TxHistory, TxType } from '../../store/interface';
import { getStore, register } from '../../store/memstore';
// tslint:disable-next-line:max-line-length
import { calCurrencyLogoUrl, currencyExchangeAvailable, fetchBalanceValueOfCoin, formatBalance, formatBalanceValue, getCurrencyUnitSymbol, getCurrentAddrByCurrencyName, getCurrentAddrInfo, parseAccount, parseStatusShow, parseTxTypeShow, timestampFormat, getCurrentAddrIndexByCurrencyName } from '../../utils/tools';
import { fetchTransactionList } from '../../utils/walletTools';
// ============================导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');

interface Props {
    currencyName: string;
    gain: number;
}
export class TransactionHome extends Widget {
    public props: any;

    public ok: () => void;
    public backPrePage() {
        this.ok && this.ok();
    }
    public setProps(props: Props, oldProps: Props) {
        super.setProps(props, oldProps);
        this.init();
        dataCenter.updateAddrInfo(getCurrentAddrInfo(this.props.currencyName).addr, this.props.currencyName);
    }
    public init() {
        const currencyName = this.props.currencyName;
        const balance = formatBalance(getCurrentAddrInfo(this.props.currencyName).balance);
        const balanceValue = fetchBalanceValueOfCoin(currencyName, balance);
        const txList = this.parseTxList();
        const canConvert = this.canConvert();
        const color = getStore('setting/changeColor', 'redUp');
        const addr = parseAccount(getCurrentAddrByCurrencyName(currencyName));
        const addrIndex = getCurrentAddrIndexByCurrencyName(currencyName)

        this.props = {
            ...this.props,
            currencyLogo: calCurrencyLogoUrl(currencyName),
            balance,
            balanceValue: formatBalanceValue(balanceValue),
            rate: formatBalanceValue(fetchBalanceValueOfCoin(currencyName, 1)),
            txList,
            canConvert,
            redUp: color === 'redUp',
            currencyUnitSymbol: getCurrencyUnitSymbol(),
            tabs: [{
                tab: '转账',
                list: this.transferList(txList)
            }, {
                tab: '收款',
                list: this.receiptList(txList)
            }],
            activeNum: this.props.activeNum ? this.props.activeNum : 0,
            address: addr,
            addrIndex
        };
        console.log(this.props);
    }
    // 解析txList
    public parseTxList() {
        const currencyName = this.props.currencyName;
        const curAddr = getCurrentAddrByCurrencyName(currencyName);
        const txList = fetchTransactionList(curAddr, currencyName);
        txList.forEach(item => {
            item.TimeShow = timestampFormat(item.time).slice(5);
            item.statusShow = parseStatusShow(item).text;
            item.txTypeShow = parseTxTypeShow(item.txType);
        });

        return txList;
    }
    /**
     * 转账记录
     */
    public transferList(txList: TxHistory[]) {
        return txList.filter(item => {
            return item.txType !== TxType.Receipt;
        });
    }
    /**
     * 收款记录
     */
    public receiptList(txList: TxHistory[]) {
        return txList.filter(item => {
            return item.txType === TxType.Receipt;
        });
    }
    /**
     * tab切换
     */
    public tabsChangeClick(value: number) {
        this.props.activeNum = value;
        this.paint();
    }

    public canConvert() {
        const convertCurrencys = currencyExchangeAvailable();
        for (let i = 0; i < convertCurrencys.length; i++) {
            if (convertCurrencys[i] === this.props.currencyName) {
                return true;
            }
        }

        return false;
    }

    public txListItemClick(e: any, index: number) {
        const txList = this.props.tabs[this.props.activeNum].list;
        popNew('blockchain-view-transaction-transactionDetails', { hash: txList[index].hash });
    }
    // 转账
    public doTransferClick() {
        popNew('blockchain-view-transaction-transfer', { currencyName: this.props.currencyName });
    }
    // 收款
    public doReceiptClick() {
        popNew('blockchain-view-transaction-receipt', { currencyName: this.props.currencyName });
    }

    public chooseAddrClick() {
        popNew('blockchain-view-transaction-chooseAddr', { currencyName: this.props.currencyName });
    }
    public updateRate() {
        this.props.rate = formatBalanceValue(fetchBalanceValueOfCoin(this.props.currencyName, 1));
        this.paint();
    }

    public convertCurrencyClick() {
        popNew('blockchain-view-coinConvert-coinConvert', { currencyName: this.props.currencyName });
    }

    public currencyUnitChange() {
        this.props.rate = formatBalanceValue(fetchBalanceValueOfCoin(this.props.currencyName, 1));
        this.props.balanceValue = formatBalanceValue(fetchBalanceValueOfCoin(this.props.currencyName, this.props.balance));
        this.props.currencyUnitSymbol = getCurrencyUnitSymbol();
        this.paint();
    }

    public refreshClick() {
        dataCenter.updateAddrInfo(getCurrentAddrInfo(this.props.currencyName).addr, this.props.currencyName);
    }
}

// ==========================本地

// 当前钱包变化
register('wallet/currencyRecords', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.init();
        w.paint();
    }
});

// 汇率变化
register('third/rate', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateRate();
    }
});

// 涨跌幅变化
register('third/currency2USDTMap', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateRate();
    }
});

// 货币单位变化
register('setting/currencyUnit', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.currencyUnitChange();
    }
});
