/**
 * 交易详情页面
 */
import { ShareType } from '../../../pi/browser/shareToPlatforms';
import { popNew } from '../../../pi/ui/root';
import { getLang } from '../../../pi/util/lang';
import { Forelet } from '../../../pi/widget/forelet';
import { Widget } from '../../../pi/widget/widget';
import { makeScreenShot } from '../../logic/native';
import { TxType, MinerFeeLevel, TxStatus, RechargeWithdrawalLog } from '../../store/interface';
import { register } from '../../store/memstore';
import { blockchainUrl, etherscanUrl } from '../../utils/constants';
// tslint:disable-next-line:max-line-length
import { canResend, copyToClipboard, parseAccount, parseStatusShow, popNewMessage, timestampFormat, parseRechargeWithdrawalLog } from '../../utils/tools';
import { fetchLocalTxByHash1 } from '../../utils/walletTools';
import { BtcApi } from '../../core/btc/api';
import { parseBtcTransactionTx, getEthTransactionByHash1 } from '../../logic/dataCenter';
import { openWebview } from '../../logic/wrap';

// ============================导出
// tslint:disable-next-line:no-reserved-keywords
declare var module: any;
export const forelet = new Forelet();
export const WIDGET_NAME = module.id.replace(/\//g, '-');
interface Props {
    hash: string;
    cloudRecord: RechargeWithdrawalLog;
}
export class TransactionDetails extends Widget {
    public props: any;
    public ok: () => void;
    public language: any;
    public setProps(props: Props, oldProps: Props) {
        super.setProps(props, oldProps);
        this.init();
    }
    public init() {
        this.language = this.config.value[getLang()];
        let tx = fetchLocalTxByHash1(this.props.hash) || this.props.chainTx;
        console.log(`transactionDetails tx is `, tx);
        const hasTx = !!tx;
        if (!tx) {
            console.log(" cloudRecord", this.props.cloudRecord);
            const txType = this.props.cloudRecord.recharge ? TxType.Recharge : TxType.Withdraw;
            tx = {
                hash: this.props.cloudRecord.hash,
                addr: "",
                txType,
                fromAddr: "-",
                toAddr: "-",
                pay: this.props.cloudRecord.amount,
                time: this.props.cloudRecord.time,
                status: TxStatus.Cancel,                            // 交易状态
                confirmedBlockNumber: 0,
                needConfirmedBlockNumber: 0,
                info: "",                                             // 交易额外信息
                currencyName: this.props.cloudRecord.currencyName,               // 货币名称
                fee: "0.00",
                nonce: -1,
                minerFeeLevel: MinerFeeLevel.Fastest
            };
            if (this.props.cloudRecord.currencyName === "BTC") {
                BtcApi.getTxInfo(this.props.cloudRecord.hash).then((res) => {
                    console.log("获取btc交易详情 success", res);
                    if (res) {
                        const addr = res.vin[0].addr;
                        const tx = parseBtcTransactionTx(addr, res, txType);
                        console.log("获取btc交易详情解析 tx", tx);
                        this.props.chainTx = tx;
                        this.init();
                        this.paint();
                    }
                });
            } else {
                getEthTransactionByHash1(this.props.cloudRecord.hash, undefined, txType).then(tx => {
                    console.log("获取eth交易详情解析 tx", tx);
                    this.props.chainTx = tx;
                    this.init();
                    this.paint();
                });
            }
        }
        let statusShow;
        let statusIcon;
        if (hasTx) {
            const obj = parseStatusShow(tx);
            statusShow = obj.text;
            statusIcon = obj.icon;
        } else {
            const obj = parseRechargeWithdrawalLog(this.props.cloudRecord);
            statusShow = obj.statusShow;
            statusIcon = obj.icon;
        }

        const qrcodePrefix = tx.currencyName === 'BTC' ? blockchainUrl : etherscanUrl;
        const webText = tx.currencyName === 'BTC' ? this.language.tips[0] : this.language.tips[1];
        this.props = {
            ...this.props,
            tx,
            timeShow: timestampFormat(tx.time),
            statusShow,
            statusIcon,
            minerFeeUnit: tx.currencyName !== 'BTC' ? 'ETH' : 'BTC',
            canResend: canResend(tx),
            qrcode: `${qrcodePrefix}${tx.hash}`,
            webText,
            showAccount: this.showAccount.bind(this)
        };
    }
    public showAccount(str: string) {
        if (str.length < 16) return str;
        return `${str.slice(0, 8)}...${str.slice(str.length - 8, str.length)}`;
    }
    public backPrePage() {
        this.ok && this.ok();
    }

    public resendClick() {
        const tx = this.props.tx;
        if (tx.txType === TxType.Recharge) {
            popNew('blockchain-view-cloudWallet-recharge', { tx, currencyName: this.props.tx.currencyName });
        } else {
            popNew('blockchain-view-transaction-transfer', { tx, currencyName: this.props.tx.currencyName });
        }
        this.ok && this.ok();
    }

    public copyToAddr() {
        copyToClipboard(this.props.tx.toAddr);
        popNewMessage(this.language.tips[2]);
    }
    public copyFromAddr() {
        copyToClipboard(this.props.tx.fromAddr);
        popNewMessage(this.language.tips[2]);
    }
    public copyHash() {
        copyToClipboard(this.props.tx.hash);
        popNewMessage(this.language.tips[2]);
    }
    public openNewWeb() {
        return;
        popNew('blockchain-components-openLink-openLink', {}, () => {
            const title = this.props.tx.currencyName === 'BTC' ? 'Blockchain' : 'Etherscan';
            // openNewActivity(this.props.qrcode, title);
            openWebview(this.props.qrcode, title, title);
        });
    }

    public updateTransaction() {
        this.init();
        this.paint();
    }

    /**
     * 分享截图
     */
    public shareScreen() {
        makeScreenShot((result) => {
            popNew('app-components-share-share', { shareType: ShareType.TYPE_SCREEN });
        }, (result) => {
            popNewMessage(this.language.shareScreen);
        });
    }
}

// 交易记录变化
register('wallet/currencyRecords', () => {
    const w: any = forelet.getWidget(WIDGET_NAME);
    if (w) {
        w.updateTransaction();
    }
});